# Experiments

Repository to collect parameter files and analysis scripts for DG experiments conducted with [`dg1d.jl`](https://git.tpi.uni-jena.de/dg/dg1d.jl).

The `phdthesis` folder contains the experiments presented in my thesis.
- advection_sine
- burgers_sine
- eulereq_blast_wave
- eulereq_sod_shock_tube
- experiments_grhd_tov
- grhd_bondi
- grhd_bondi_infall
- grhd_tov
- srhd_simple_wave

## Instructions on how to reproduce results

0. Install Julia
    - `curl -fsSL https://install.julialang.org | sh`
    - Install version 1.10
        - `juliaup add 1.10`
        - `juliaup default 1.10`
1. Setup `dg1d.jl`
    - `git clone git@git.tpi.uni-jena.de:fatteneder/dg1d.jl.git`
2. Prepare `dg1d.jl` to run the experiments
    - In theory the latest version of `dg1d.jl` should be able to reproduce the results,
      because we employ integration tests to catch regressions in development.
      However, such tests cannot cover all possiblities, and so some results could change.
      In particular, SRHD and GRHD simulations with shocks can be very sensitive to subtle changes.
    - If exact reproducability of the results from the thesis is desired,
      follow the instructions below to restore the project state with which the plots from
      the thesis were generated. Otherwise just try current `main` version of `dg1d`.
      Restore project state:
        1. Pick the expirement you want to repeat and navigate to that folder.
           In that folder you find subfolders, one for each run of the experiment, which
           contain three files.
           - A `foldername.toml` file with the parameters.
           - A `Manifest.toml` file with package versions.
           - A `dirty` file with the git commit and potential uncommited changes.
           (In theory, `Manifest.toml` and `dirty` should be the same for all subfolders,
            because all experiments are typically run at the same time. But just double check
            in case I forgot to commit something.)
        2. Restore the git commit.
            - Go to `dg1d.jl` and `git checkout` the commit listed at the top of the `dirty` file.
            - If `dirty` contains uncommited changes, then copy `dirty` to the `dg1d.jl` folder,
              remove the first two lines with the git commit hash from the `dirty` file,
              and run `git apply dirty`.
              (in general `dirty` should not contain changes, and I haven't really tested
              the patching yet)
            - Replace the current `Manifest.toml` in `dg1d.jl` with the one from the experiment folder.
            - Run
              ```
              $ julia --project # inside the dg1d.jl directory
              julia> using Pkg
              julia> Pkg.instantiate() # should restore versions used when the experiments were run
              ```
3. Run the experiments
```
$ julia --project --threads 8 # only affects GRHD and SRHD projects where the c2p is threaded
julia> using dg1d
julia> main("/path/to/parameter/file")
```

## Helper to run many tests at once

- Extract `.toml` files from a folder `"/path/to/experiments/phdthesis/advection_sine"` and run them:
```
julia> paths = readdir("/path/to/experiments/phdthesis/advection_sine", join=true)
julia> parfiles = String[]
julia> for path in paths
          isdir(path) || continue
          ps = readdir(path, join=true)
          for p in ps
             if endswith(p, ".toml") && filename(p) != "Manifest.toml"
                push!(parfiles, p)
             end
          end
       end
julia> for p in parfiles
          try main(p); catch; end
       end
```

- Extract plotting scripts from a folder `"/path/to/experiments/phdthesis/advection_sine"` and run them:
```
julia> scripts = readdir("/path/to/experiments/phdthesis/advection_sine", join=true)
julia> filter!(scripts) do f
          isfile(f) && endswith(f, ".jl") && startswith(f, "plot_")
       end
julia> for s in scripts
          try include(s); catch; end
       end
```
