using DataFrames
using Printf


include("../utils.jl")


rootdir = joinpath(@__DIR__)
do_cvg_analysis = true


paths = readdir(rootdir, join=true)
filter!(paths) do p
    isdir(p) && match(r"dg_\D+_.*", p) |> !isnothing && !endswith(p, "previous")
end


# load data
df = DataFrame()
rgx = r"dg_(.*)_(.*)_(.*)"
for p in paths
    m = match(rgx, basename(p)) |> something
    basis, n, k = m[1], tryparse(Int64, m[2]), tryparse(Int64, m[3])
    run = readdata(p, ["u_err_norm"], output="output0d.h5")
    # u_err_norm is 0d output, so we collapse the 0d output from each time step into a single array
    u_err_norm = [ only(err) for err in run.u_err_norm ]
    u_err_norm_end = u_err_norm[end]
    t = run.t
    push!(df, (; t, u_err_norm, u_err_norm_end, run, outputdir=p, basis, n, k))
end


if do_cvg_analysis
    # bases = [ "lgl", "lgl_lumped", "glgl" ]
    bases = sort(unique(df.basis))
    ns = sort(unique(df.n))
    ks = sort(unique(df.k))
    data = []
    cvgrate = []
    for basis in bases
        subdf = filter(df) do row
            row.basis == basis
        end

        data_fixed_n = zeros(Float64, (length(ks),length(ns)))
        cvg_rate_fixed_n = zeros(Float64, (length(ks),length(ns)))
        for (j,n) in enumerate(ns)
            sdf = filter(subdf) do row
                row.n == n
            end
            sort!(sdf, :k)
            data_fixed_n[:,j] .= sdf.u_err_norm_end
            cvg_rate_fixed_n[1,j] = NaN
            for i in 1:length(sdf.u_err_norm_end)-1
                e1, e2 = sdf.u_err_norm_end[[i,i+1]]
                k1, k2 = ks[[i,i+1]]
                cvg = log(e1/e2)/log(k2/k1)
                cvg_rate_fixed_n[i+1,j] = cvg
            end
        end

        push!(data, data_fixed_n)
        push!(cvgrate, cvg_rate_fixed_n)

    end

    # combine cvg results wrt polynomial order
    for (i,n) in enumerate(ns)

        filename = joinpath(@__DIR__,"cvgseries_n_$(n).tex")
        open(filename, "w") do io
            for j in 1:length(ks)
                print(io, j == 1 ? n : " ", " & ",  ks[j], " ")
                for b in 1:length(bases)
                    d, cvg = data[b][j,i], cvgrate[b][j,i]
                    p = Int64(floor(log10(d)))
                    v = @sprintf "%.2f" d*10.0^(-p)
                    c = isnan(cvg) ? "-" : @sprintf "%.2f" cvg
                    print(io, "& & \$$v \\times 10^{$p}\$ & $c ")
                end
                print(io, "\\\\")
                j < length(ks) && print(io, "\n")
            end
            print(io, " \\hline\n")
        end
    end

    nidxs = [ findfirst(==(ni), ns) for ni in 3:2:9 ]

    # combine cvg results wrt basis
    for (b,basis) in enumerate(bases)

        filename = joinpath(@__DIR__,"cvgseries_$(basis).tex")
        open(filename, "w") do io
            for j in 1:length(ks)
                print(io, ks[j], " ")
                for (i,n) in enumerate(ns[nidxs])
                    d, cvg = data[b][j,nidxs[i]], cvgrate[b][j,nidxs[i]]
                    p = Int64(floor(log10(d)))
                    v = @sprintf "%.2f" d*10.0^(-p)
                    c = isnan(cvg) ? "-" : @sprintf "%.2f" cvg
                    print(io, "& & \$$v \\times 10^{$p}\$ & $c ")
                end
                if j < length(ks)
                    print(io, "\\\\")
                    print(io, "\n")
                end
            end
            # print(io, " \\hline\n")
        end
    end

end
