#!/usr/bin/env julia

using TOML

template = """
[Evolution]
cfl = 0.2
tend = "\$(pi+0.0)"
method = "rkf10"

[Output]
variables1d = [ "u" ]
variables0d = [ "u_err_norm" ]
aligned_ts = "\$(collect(range(1.0,5*pi,step=1.0)))"

[ScalarEq]
equation = "advection"
id = "sine"
advection_v = 1.0
analyze_error = true
analyze_error_norm = true

[Mesh]
range = "\$([0.0,5*pi])"
"""

tmpl = TOML.parse(template)

bases = [ "lgl", "lgl_lumped", "glgl" ]
ks = [2, 4, 8, 16, 32, 64]
ns = [1, 2, 3, 4, 5, 6, 7, 8, 9]
for n in ns, k in ks, b in bases
    name = "dg_$(b)_$(n)_$(k).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["n"] = n
        prms["Mesh"]["k"] = k
        prms["Mesh"]["basis"] = b
        TOML.print(file, prms)
    end
end
