using TOML


## AV+MDA

template = """
[Evolution]
cfl = 0.2
tend = 0.6
method = "rk4"

[Output]
variables1d = [ "u", "smoothed_mu" ]
aligned_ts = "\$(collect(range(0.01,0.6,step=0.01)))"

[ScalarEq]
equation = "burgers"
id = "sine"

[Mesh]
range = [0, 1]
basis = "lgl"

[HRSC]
method = "av"
av_method = "mda"
"""

tmpl = TOML.parse(template)

cmax = [ 1, 5 ]
ks = [21, 41, 81, 161]
ns = [4, 5, 6, 7, 8, 9]
for n in ns, k in ks, cm in cmax
    name = "avmda_$(n)_$(k)_cmax_$(cm).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["n"] = n
        prms["Mesh"]["k"] = k
        prms["HRSC"]["mda_cmax"] = Float64(cm)
        prms["Output"]["interpolate_aligned_ts"] = """ \$(collect(0.1:0.1:0.6))  """
        prms["Output"]["interpolate_variables"] = ["u"]
        prms["Output"]["interpolate_nodes"] = """ \$(collect(range(0.0,1.0,length=500))) """
        TOML.print(file, prms)
    end
end


## No HRSC

template = """
[Evolution]
cfl = 0.2
tend = 0.6
method = "rk4"

[Output]
variables1d = [ "u" ]
aligned_ts = "\$(collect(range(0.01,0.6,step=0.01)))"

[ScalarEq]
equation = "burgers"
id = "sine"

[Mesh]
range = [0, 1]
basis = "lgl"
"""

tmpl = TOML.parse(template)

cmax = [ 1, 5 ]
ks = [21, 41, 81, 161]
ns = [4, 5, 6, 7, 8, 9]
for n in ns, k in ks
    name = "dg_$(n)_$(k).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["n"] = n
        prms["Mesh"]["k"] = k
        TOML.print(file, prms)
    end
end


## FV+MUSCL

template = """
[Evolution]
cfl = 0.2
tend = 0.6
method = "rk4"

[Output]
variables1d = [ "u" ]
aligned_ts = "\$(collect(range(0.01,0.6,step=0.01)))"

[ScalarEq]
equation = "burgers"
id = "sine"
hrsc = "slope_limiter"
slope_limiter_method = "tvb"

[Mesh]
range = [0, 1]
scheme = "FV"
k = 1024
"""

tmpl = TOML.parse(template)

name = "fv_muscl_1024.toml"
open(joinpath(@__DIR__,name), "w") do file
    prms = deepcopy(tmpl)
    TOML.print(file, prms)
end
