using TOML


## AV+MDA

template = """
[EquationOfState]
eos = "idealgas"
idealgas_gamma = 1.4

[EulerEq]
bc = "from_id"
id = "sod_shock_tube"
av_regularization = "mono"

[Mesh]
range = [ 0.0, 1.0 ]
basis = "lgl"
periodic = [ false ]

[Output]
aligned_ts = "\$(collect(range(0.01,0.4,step=0.01)))"
variables1d     = [ "rho", "q", "E", "smoothed_mu", "v", "p" ]

[Evolution]
tend = 0.25
cfl = 0.2
method = "rk4"

[HRSC]
method = "av"
av_method = "mda"
av_cmax = 1.0
"""

tmpl = TOML.parse(template)

ks = [40, 80, 160, 320]
ns = [5]
for n in ns, k in ks
    name = "avmda_$(n)_$(k).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["n"] = n
        prms["Mesh"]["k"] = k
        TOML.print(file, prms)
    end
end
