using TOML


## DG

template = """
[EquationOfState]
eos = "polytrope"
polytrope_k = 0.02143872868864732
polytrope_gamma = $(4/3)

[GRHD]
bc = "from_id"
id = "bondi_accretion"
id_filename = "\$(joinpath(ROOTDIR,\\"initialdata\\",\\"bondi_accretion_highres.h5\\"))"
variables0d_analyze_error = ["ρ", "D"]
variables1d_analyze_error = ["ρ", "D"]
analyze_error_reference_solution = "bondi_accretion"
c2p_enforce_atm = false
c2p_enforce_causal_atm = false
c2p_set_atmosphere_on_failure = true

[Mesh]
range = [ 1.8, 20.0 ]
basis = "lgl"
periodic = false

[Output]
variables0d = [ "ρ_err_norm", "D_err_norm" ]
variables1d = [ "ρ_err", "D_err", "D", "Sr", "τ", "p", "ρ", "ϵ", "vr" ]
aligned_ts = $(collect(range(1.0,300.0,step=1.0)))

[Evolution]
cfl = 0.2
tend = 300.0
method = "rk4"
"""

tmpl = TOML.parse(template)

ks = [8, 16, 32, 64]
ns = [1, 3, 5, 7]
for n in ns, k in ks
    name = "dg_n$(n)_k$(k).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["n"] = n
        prms["Mesh"]["k"] = k
        TOML.print(file, prms)
    end
end
