using TOML


## AV+DG

template = """
[EquationOfState]
eos = "polytrope"
polytrope_k = 0.02143872868864732
polytrope_gamma = $(4/3)

[GRHD]
formulation = "spherical1d"
bc = "from_id"
id = "bondi_accretion_infall"
variables0d_analyze_error = ["ρ", "D"]
variables1d_analyze_error = ["ρ", "D"]
analyze_error_reference_solution = "bondi_accretion"
c2p_enforce_causal_atm = false
av_sensor_abslog_D = true

[Mesh]
range = [ 1.8, 20.0 ]
basis = "lgl"
periodic = false

[Output]
variables0d = [ "ρ_err_norm", "D_err_norm" ]
variables1d = [ "ρ_err", "D_err", "D", "Sr", "τ", "p", "ρ", "ϵ", "vr", "γrr", "smoothed_mu" ]
aligned_ts = $(collect(range(1.0,300.0,step=1.0)))

[Evolution]
cfl = 0.2
tend = 300.0
method = "rk4"

[HRSC]
method = "av"
av_method = "mda"
mda_cmax = 1.0
"""

tmpl = TOML.parse(template)

ks = [8, 16, 32, 64]
ns = [5, 7, 9]
for n in ns, k in ks
    name = "dg_n$(n)_k$(k).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["n"] = n
        prms["Mesh"]["k"] = k
        TOML.print(file, prms)
    end
end
