#!/usr/bin/env julia

using TOML

template = raw"""
[EquationOfState]
polytrope_gamma = 2.0
polytrope_k = 100.0
eos = "polytrope"

[Output]
aligned_ts = "$(collect(range(1.0,2000.0,step=1.0)))"
variables1d = [ "D", "Sr", "τ",
                "rhs_D", "rhs_Sr", "rhs_τ",
                "ρ", "p", "vr",
                "D_err", "ρ_err",
                "c2p_reset_atm",
                "smoothed_mu" ]
variables0d = [ "Mtot" ]

[Evolution]
cfl = 0.8
tend = 2000.0
method = "rk4"

[GRHD]
variables1d_analyze_error = ["ρ", "D"]
c2p_threshold_velocity_limiter = 0.0
atm_threshold_factor = 100.0
bc = "tov_symmetric_domain"
analyze_error_reference_solution = "from_id"
id_filename = "$(joinpath(ROOTDIR,\\"initialdata\\",\\"TOV_stable.h5\\"))"
id = "tov"
formulation = "spherical1d"
c2p_enforce_atm = true
freeze_vars = ["τ"]
doublecartoon_disable_derivatives = true
atm_evolve = false
av_sensor_abslog_D = true
variables0d_analyze = [ "Mtot" ]

[Mesh]
periodic = false
range = [-20.0, 20.0]
n = 5
scheme = "DG"

[HRSC]
method = "av"
av_method = "mda"
mda_cmax = 0.1
"""

tmpl = TOML.parse(template)

ks = [21,41,81,161]
for k in ks
    name = "k_$(k).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["k"] = k
        TOML.print(file, prms)
    end
end
