include(joinpath(@__DIR__, "..", "helpers.jl"))

let
with_theme(theme; fontsize=30) do

fv = load_data(joinpath(@__DIR__,"..","fv"), "k_512")

dg_1 = load_data(@__DIR__, "k_21")
# dg_2 = load_data(@__DIR__, "k_31")
dg_3 = load_data(@__DIR__, "k_41")
# dg_4 = load_data(@__DIR__, "k_51")
dg_5 = load_data(@__DIR__, "k_61")
# dg_6 = load_data(@__DIR__, "k_71")
dg_7 = load_data(@__DIR__, "k_81")
# dg_8 = load_data(@__DIR__, "k_91")
dg_9 = load_data(@__DIR__, "k_101")

dg_data = [ dg_1, dg_3, dg_5, dg_7, dg_9 ]


t_SI = 4.9266e-6 # s
l_SI = 1.4769    # km
f_SI = 1/t_SI    # Hz
# ref frequencies
f_ref = [ (2.696,2.701), (4.534,4.563), (6.346,6.352), (8.129,8.161),
          (9.875,9.971), (11.657,11.806), (13.421,13.605) ] # kHz


#######################################################################
#                          surface alignment                          #
#######################################################################


fig = Figure(size=(1400,400))
gl = fig[1,1] = GridLayout()

N = length(dg_data)
axs_logD = [ Axis(gl[1,i], xlabel=L"r~[\text{km}]",
                  ytickformat= vals -> [ @sprintf("%.0f",v) for v in vals ]) for i in 1:N ]

Label(gl[1:end,0], text=L"\log_{10}(D(t,r))",
      rotation=π/2, tellwidth=true, tellheight=false)

plts = Any[]
for i in 1:N
    ax_logD = axs_logD[i]
    dg = dg_data[i]
    x = dg.x
    D = dg.D
    scatterlines!(ax_logD, x .* l_SI, log10.(abs.(D[1])),
                  color=:black, markersize=15)
    scatterlines!(ax_logD, x .* l_SI, log10.(abs.(D[end])),
                  color=colors[i])
    xbdrys = vcat(x[1], x[findall(i->x[i]≈x[i+1], 1:length(x)-1)], x[end])
    lbl = L"K = %$(dg.k)"
    vlines!(ax_logD, xbdrys .* l_SI, color=colors[i], linestyle=:dash, label=lbl)
    if i == 1
        for j in 2:N
            lbl = L"K = %$(dg_data[j].k)"
            vlines!(ax_logD, xbdrys .* l_SI, color=colors[j], linestyle=:dash, label=lbl,
                    visible=false)
        end
    end
end

for i in 1:N
    if i > 1
        hideydecorations!(axs_logD[i], grid=false, minorgrid=false, ticks=false, minorticks=false)
    end
    xlims!(axs_logD[i], (10.25,13.75))
    axs_logD[i].xticks[] = 10:1.0:14
end

Legend(gl[0,1:N], axs_logD[1], colgap=20, width=nothing,
       orientation=:horizontal, nbanks=1,
       tellwidth=false, tellheight=true)
rowgap!(fig.layout, 0)
for i in 2:N
    colgap!(gl, i, 0)
end


plotname = joinpath(@__DIR__, "$(basename(@__DIR__))_surface.png")
save(plotname, fig)



#######################################################################
#                        plot central density                         #
#######################################################################

fig = Figure(size=(1400,400))
gl = fig[1,1] = GridLayout()

ax    = Axis(gl[1,1], xlabel=L"t~[\text{ms}]",
             ytickformat= vals -> [ @sprintf("%.3f",v) for v in vals ])
ax_ft = Axis(gl[1,2], xlabel=L"f~[\text{kHz}]", yaxisposition=:right)

Label(gl[1,0], text=L"\rho_{c}(t)/\rho_{c}(t=0)",
      rotation=π/2, tellwidth=true, tellheight=false)
Label(gl[1,3], text=L"\log_{10}(\text{PSD})",
      rotation=π/2, tellwidth=true, tellheight=false)


for (f_low,f_up) in f_ref
    vlines!(ax_ft, f_low, linestyle=:dash, color=:gray, linewidth=1)
    vlines!(ax_ft, f_up, linestyle=:dash, color=:gray, linewidth=1)
    band!(ax_ft, [f_low,f_up], 100.0, -100.0, color=(:gray,0.3))
end

lines!(ax, fv.t.*t_SI*1e3, fv.norm_ρctr, label=L"\text{FV},~K = %$(fv.k)",
       color=:black, linestyle=:dash)
lines!(ax_ft, fv.f.*f_SI/1e3, log10.(fv.norm_psd),
       color=:black, linestyle=:dash)

plot_lines = (data, color) -> begin
    lbl = L"K = %$(data.k)"
    lines!(ax, data.t.*t_SI*1e3, data.norm_ρctr, label=lbl;
           color)
    lines!(ax_ft, data.f.*f_SI/1e3, log10.(data.norm_psd);
           color)
end

plot_lines(dg_1, (colors[1],0.4))
plot_lines(dg_3, (colors[2],0.4))
plot_lines(dg_5, colors[3])
plot_lines(dg_7, colors[4])
plot_lines(dg_9, (colors[5],0.4))


# xlims!(ax, (0.0,5.5))
ylims!(ax, (0.995,1.035))
xlims!(ax_ft, (0.0,16.0))
ylims!(ax_ft, (-14.0,-5.0))
ax.xticks[] = 0.0:1.0:10.0
ax.yticks[] = 0.99:0.01:1.03
ax_ft.xticks[] = 0:2:16

Legend(gl[0,1:2], ax, colgap=20, width=nothing,
       orientation=:horizontal, nbanks=1,
       tellwidth=false, tellheight=true)
rowgap!(fig.layout, 0)


plotname = joinpath(@__DIR__, "$(basename(@__DIR__))_rho_ctr.png")
save(plotname, fig)

#######################################################################
#                        plot restmass density                        #
#######################################################################

plotname = joinpath(@__DIR__, "$(basename(@__DIR__))_Mtot.png")

fig = Figure(size=(1500,400))
gl = fig[1,1] = GridLayout()

ax_Mtot = Axis(gl[1,1], xlabel=L"t~[\text{ms}]",
               ytickformat= vals -> [ @sprintf("%.3f",v) for v in vals ])
ax_D    = Axis(gl[1,2], xlabel=L"r~[\text{km}]",
               yaxisposition=:right)
Label(gl[1,0], text=L"1-M_{\textrm{tot}}(t)/M_{\textrm{tot}}(0)",
      rotation=π/2, tellwidth=true, tellheight=false)
# Label(gl[1,3], text=L"D(t,r) - D(0,r)",
Label(gl[1,3], text=L"\log_{10}(D(t,r))",
      rotation=π/2, tellwidth=true, tellheight=false)

lines!(ax_Mtot, fv.t0d.*t_SI*1e3, 1.0 .- fv.Mtot/fv.Mtot[1], label=L"\text{FV},~K = %$(fv.k)",
       color=:black, linestyle=:dash)
lines!(ax_D, fv.x.*l_SI, log10.(abs.(fv.D[end])),
       color=:black, linestyle=:dash)

plot_lines = (data, color) -> begin
    lbl = L"K = %$(data.k)"
    lines!(ax_Mtot, data.t0d.*t_SI*1e3, 1.0 .- data.Mtot/data.Mtot[1], label=lbl;
           color)
    # lines!(ax_Mtot, data.t0d.*t_SI*1e3, data.Mtot, label=lbl;
    #        color)
    # lines!(ax_D, data.x.*l_SI, data.D_err[end];
    #        color)
    lines!(ax_D, data.x.*l_SI, log10.(abs.(data.D[end]));
           color)
end

for (i,dg) in enumerate(dg_data)
    plot_lines(dg, colors[i])
end

ax_Mtot.xticks[] = 0.0:1.0:10.0
ax_D.xticks[] = -40.0:10.0:40.0

Legend(gl[0,1:2], ax_Mtot, colgap=20, width=nothing,
       orientation=:horizontal, nbanks=1,
       tellwidth=false, tellheight=true)
rowgap!(fig.layout, 0)

save(plotname, fig)

end
end
