#!/usr/bin/env julia

using TOML

template = raw"""
[EquationOfState]
polytrope_gamma = 2.0
polytrope_k = 100.0
eos = "polytrope"

[Evolution]
method = "rk4"
cfl = 0.2
tend = 2000.0

[Output]
variables0d = ["Mtot"]
aligned_ts = "$(collect(range(1.0,2000.0,step=1.0)))"
variables1d = ["D", "Sr", "τ", "rhs_D", "rhs_Sr", "rhs_τ", "ρ", "p", "vr", "D_err", "ρ_err", "c2p_reset_atm", "c2p_freeze_atm"]

[GRHD]
c2p_threshold_velocity_limiter = 1.0e-8
c2p_set_atmosphere_on_failure = true
c2p_enforce_causal_atm = false
c2p_enforce_atm = false
atm_evolve = false
variables1d_analyze_error = ["ρ", "D"]
variables0d_analyze = ["Mtot"]
analyze_error_reference_solution = "from_id"
atm_threshold_factor = 100.001
id_filename = "$(joinpath(ROOTDIR,\\"initialdata\\",\\"TOV_stable.h5\\"))"
atm_factor = 1.0e-10
id = "tov"
formulation = "spherical1d"
bc = "tov_symmetric_domain"
freeze_vars = ["τ"]
dt_min_grid_spacing = true
limiter = true
limiter_tci_method = "mda"
limiter_tci_threshold = 0.1
limiter_limit_log_D = true

[Mesh]
periodic = false
dg_kind = "modal_bspline2"
range = [-20.0, 20.0]
basis = "lgl"
n = 5
"""

tmpl = TOML.parse(template)

ks = [21,31,41,51,61,71,81,91,101]
for k in ks
    name = "k_$(k).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["k"] = k
        TOML.print(file, prms)
    end
end
