#!/usr/bin/env julia

using TOML

template = raw"""
[EquationOfState]
polytrope_gamma = 2.0
polytrope_k = 100.0
eos = "polytrope"

[Output]
aligned_ts = "$(collect(range(1.0,2000.0,step=1.0)))"
variables1d = ["D", "Sr", "rhs_D", "rhs_Sr", "rhs_τ", "ρ", "p", "vr", "D_err", "ρ_err"]
variables0d = [ "Mtot" ]

[Evolution]
cfl = 0.8
tend = 2000.0

[GRHD]
slope_limiter_method = "mc"
variables1d_analyze_error = ["ρ", "D"]
c2p_threshold_velocity_limiter = 1.0e-8
bc = "tov_symmetric_domain"
analyze_error_reference_solution = "from_id"
id_filename = "$(joinpath(ROOTDIR,\\"initialdata\\",\\"TOV_stable.h5\\"))"
id = "tov"
hrsc = "slope_limiter"
formulation = "spherical1d"
c2p_enforce_atm = true
fv_numerical_flux = "llf"
freeze_vars = ["τ"]
doublecartoon_disable_derivatives = true
variables0d_analyze = [ "Mtot" ]

[Mesh]
periodic = false
range = [-20.0, 20.0]
scheme = "FV"
"""

tmpl = TOML.parse(template)

ks = [128,256,512,1024]
for k in ks
    name = "k_$(k).toml"
    open(joinpath(@__DIR__,name), "w") do file
        prms = deepcopy(tmpl)
        prms["Mesh"]["k"] = k
        TOML.print(file, prms)
    end
end
