include(joinpath(@__DIR__, "..", "helpers.jl"))

let
with_theme(theme; fontsize=30) do

fv1 = load_data(@__DIR__,"k_128")
fv2 = load_data(@__DIR__,"k_256")
fv3 = load_data(@__DIR__,"k_512")
fv4 = load_data(@__DIR__,"k_1024")


t_SI = 4.9266e-6 # s
l_SI = 1.4769    # km
f_SI = 1/t_SI    # Hz
# ref frequencies, in kHz
f_ref = [ (2.696,2.701), (4.534,4.563), (6.346,6.352), (8.129,8.161),
                (9.875,9.971), (11.657,11.806), (13.421,13.605) ]


#######################################################################
#                        plot central density                         #
#######################################################################


fig = Figure(size=(1400,500))
gl = fig[1,1] = GridLayout()

ax    = Axis(gl[1,1], xlabel=L"t~[\text{ms}]",
             ytickformat= vals -> [ @sprintf("%.3f",v) for v in vals ])
ax_ft = Axis(gl[1,2], xlabel=L"f~[\text{kHz}]", yaxisposition=:right)

Label(gl[1,0], text=L"\rho_{c}(t)/\rho_{c}(t=0)",
      rotation=π/2, tellwidth=true, tellheight=false)
Label(gl[1,3], text=L"\log_{10}(\text{PSD})",
      rotation=π/2, tellwidth=true, tellheight=false)


for (f_low,f_up) in f_ref
    vlines!(ax_ft, f_low, linestyle=:dash, color=:gray, linewidth=1)
    vlines!(ax_ft, f_up, linestyle=:dash, color=:gray, linewidth=1)
    band!(ax_ft, [f_low,f_up], 100.0, -100.0, color=(:gray,0.3))
end


function plot_lines(data, color)
    lbl = L"K = %$(data.k)"
    lines!(ax, data.t.*t_SI*1e3, data.norm_ρctr, label=lbl;
           color)
    lines!(ax_ft, data.f.*f_SI/1e3, log10.(data.norm_psd);
           color)
end

plot_lines(fv1, colors[1])
plot_lines(fv2, colors[2])
plot_lines(fv3, colors[3])
plot_lines(fv4, colors[4])


# xlims!(ax, (0.0,5.5))
ylims!(ax, (0.995,1.035))
xlims!(ax_ft, (0.0,16.0))
ylims!(ax_ft, (-14.0,-5.0))
ax.xticks[] = 0.0:1.0:10.0
ax.yticks[] = 0.99:0.01:1.03
ax_ft.xticks[] = 0:2:16

Legend(gl[0,1:2], ax, colgap=20, width=nothing,
       orientation=:horizontal, nbanks=1,
       tellwidth=false, tellheight=true)
rowgap!(fig.layout, 0)

plotname = joinpath(@__DIR__, "$(basename(@__DIR__))_cvg.png")
save(plotname, fig)


#######################################################################
#                        plot restmass density                        #
#######################################################################

plotname = joinpath(@__DIR__, "$(basename(@__DIR__))_Mtot.png")

fig = Figure(size=(1500,500))
gl = fig[1,1] = GridLayout()

ax_Mtot = Axis(gl[1,1], xlabel=L"t~[\text{ms}]",
               ytickformat= vals -> [ @sprintf("%.3f",v) for v in vals ])
ax_D    = Axis(gl[1,2], xlabel=L"r~[\text{km}]",
               yaxisposition=:right)
Label(gl[1,0], text=L"1-M_{\textrm{tot}}(t)/M_{\textrm{tot}}(0)",
      rotation=π/2, tellwidth=true, tellheight=false)
Label(gl[1,3], text=L"D(t,r) - D(0,r)",
      rotation=π/2, tellwidth=true, tellheight=false)

plot_lines = (data, color) -> begin
    lbl = L"K = %$(data.k)"
    lines!(ax_Mtot, data.t0d.*t_SI*1e3, 1.0 .- data.Mtot/data.Mtot[1], label=lbl;
           color)
    # lines!(ax_Mtot, data.t0d.*t_SI*1e3, data.Mtot, label=lbl;
    #        color)
    lines!(ax_D, data.x.*l_SI, data.D_err[end];
           color)
end

plot_lines(fv1, colors[1])
plot_lines(fv2, colors[2])
plot_lines(fv3, colors[3])
plot_lines(fv4, colors[4])

ax_Mtot.xticks[] = 0.0:1.0:10.0
ax_D.xticks[] = -40.0:10.0:40.0

Legend(gl[0,1:2], ax_Mtot, colgap=20, width=nothing,
       orientation=:horizontal, nbanks=1,
       tellwidth=false, tellheight=true)
rowgap!(fig.layout, 0)

save(plotname, fig)


end
end
