using CairoMakie
using HDF5
using FFTW
using Printf
using TOML

include(joinpath(@__DIR__,"..","..","theme.jl"))
include(joinpath(@__DIR__,"..","..","utils.jl"))

function analyze_rho(rootdir,dir)
    @assert isdir(joinpath(rootdir,dir)) "missing output directory $(joinpath(rootdir,dir))"

    data = readdata(joinpath(rootdir, dir), ["ρ"], output="output1d.h5")
    pars = TOML.parsefile(joinpath(rootdir,dir,"$(basename(dir)).toml"))

    t = data.t
    x = data.x
    f = fftshift(fftfreq(length(t),1/(t[2]-t[1])))
    ρ = data.ρ
    ρctr = [ ρt[something(findfirst(xi -> xi>=0.0, x))] for ρt in ρ ]
    norm_ρctr = ρctr/ρctr[1]
    ft_ρctr = fftshift(fft(norm_ρctr))
    psd = @. abs(ft_ρctr)^2
    norm_psd = psd./maximum(psd)

    k = pars["Mesh"]["k"]
    # vlimit = pars["GRHD"]["c2p_threshold_velocity_limiter"]
    vlimit = NaN

    return (; data, pars, t, x, f, ρ, ρctr, norm_ρctr, ft_ρctr, psd, norm_psd,
              k, vlimit)
end

function load_data(rootdir, dir; x0=0.0)
    @assert isdir(joinpath(rootdir,dir)) "missing output directory $(joinpath(rootdir,dir))"

    data1d = readdata(joinpath(rootdir, dir), ["ρ","D_err","D"], output="output1d.h5")
    pars = TOML.parsefile(joinpath(rootdir,dir,"$(dir).toml"))

    t = data1d.t
    x = data1d.x
    f = fftshift(fftfreq(length(t),1/(t[2]-t[1])))
    ρ = data1d.ρ
    D = data1d.D
    D_err = data1d.D_err
    ρctr = [ ρt[something(findfirst(xi -> xi>=x0, x))] for ρt in ρ ]
    norm_ρctr = ρctr/ρctr[1]
    ft_ρctr = fftshift(fft(norm_ρctr))
    psd = @. abs(ft_ρctr)^2
    norm_psd = psd./maximum(psd)

    k = pars["Mesh"]["k"]
    # vlimit = pars["GRHD"]["c2p_threshold_velocity_limiter"]
    vlimit = NaN

    data0d = readdata(joinpath(rootdir, dir), ["Mtot"], output="output0d.h5")
    t0d = data0d.t
    Mtot = [  reduce(first, Mtots) for Mtots in data0d.Mtot ]
    return (; data0d, data1d, pars, t, t0d, x, f, ρ, D, D_err, ρctr, norm_ρctr, ft_ρctr, psd, norm_psd,
              k, vlimit, Mtot)

    # return (; data0d, data1d, pars, t, t0d, x, f, ρ, ρctr, norm_ρctr, ft_ρctr, psd, norm_psd,
    #           k, vlimit, Mtot)
end
